
/**
 * @file
 * Default markItUp! tweakers.
 *
 * This file implements two basic "tweakers," which is what I'm choosing to call
 * add-on functions which alter the behavior of a markItUp! editor. In doing so,
 * I also hope this file will be of use to others who wish to write their own
 * tweakers. These functions are called, one at a time, right before markItUp!
 * is attached to a textarea and/or the input filter the user is using is
 * changed.
 */

/*global Drupal, $, mySettings */

// Note that there is no Drupal.behaviors function. If you try to append your
// tweaker from inside a Drupal.behaviors function, the markItUp! module's
// Drupal.behaviors function will be called before your function, so you won't
// be able to add your tweaker before markItUp! needs to use it. So add your
// function directly to the Drupal.settings.markItUp.tweakers array (which
// should already be declared at this point).

// Note that we have to introduce a new namespace at the Drupal.settings level.
// Initially I was trying to put all tweakers in
// Drupal.settings.markItUp.tweakers, but that didn't work because
// Drupal.settings.markItUp isn't created at this point, and gets overwritten
// if we try to create it.

Drupal.settings.markItUpTweakers.drupalBreak = function(ifidx) {
	// The selected input filter's (one-based) index is passed as an integer in
	// the if value. We're going to check Drupal.settings.markItUp.data[if].tweaks
	// to see if we should do our stuff.
	// Note that adding a Drupal break button is "default" behavior, so we're
	// going to add it if its tweak value is undefined.
	if (typeof(Drupal.settings.markItUp.data[ifidx].tweaks.drupalBreak) == 'undefined' || Drupal.settings.markItUp.data[ifidx].tweaks.drupalBreak) {
		mySettings.markupSet.push({
			'name': 'Drupal Break',
			'className': 'markItUpDrupalBreak',
			'key': 'K',
			'replaceWith': '\n\n<!--break-->\n\n'
		});
	}
//	$('body').append($('<style>').attr('type', 'text/css').html('.markItUpDrupalBreak A{background-image: url("' + Drupal.settings.markItUp.path + '../misc/break.png");'));
};

Drupal.settings.markItUpTweakers.previewOverride = function(ifidx) {
	// Possible values of Drupal.settings.markItUp.data[if].tweaks.previewOverride
	// 0: Do not override
	// 1: Map to Drupal's Preview button
	// 2: Remove it (default)
	if (typeof(Drupal.settings.markItUp.data[ifidx].tweaks.previewOverride) === 'undefined' || Drupal.settings.markItUp.data[ifidx].tweaks.previewOverride > 0) {
		var newMarkupSet = [];
		jQuery.each(mySettings.markupSet, function(i, button) {
			if (typeof(button.name) !== 'undefined' && button.name === 'Preview') {
				if (Drupal.settings.markItUp.data[ifidx].tweaks.previewOverride === 1) {
					button.call = function() {
						$('#edit-preview').click();
					};
					newMarkupSet.push(button);
				}
			}
			else {
				newMarkupSet.push(button);
			}
		});
		mySettings.markupSet = newMarkupSet;
	}
};